KeyboardTrackingQueryFlagsFB

Struct KeyboardTrackingQueryFlagsFB 

pub struct KeyboardTrackingQueryFlagsFB(/* private fields */);
Implementations

Source

impl KeyboardTrackingQueryFlagsFB

pub const LOCAL: KeyboardTrackingQueryFlagsFB

indicates the query is for the physically tracked keyboard that is intended to be used in a local pairing with the System. Mutually exclusive with XR_KEYBOARD_TRACKING_QUERY_REMOTE_BIT_FB.

pub const REMOTE: KeyboardTrackingQueryFlagsFB

indicates the query is for the physically tracked keyboard that may be connected to a separate remote computing device. Mutually exclusive with XR_KEYBOARD_TRACKING_QUERY_LOCAL_BIT_FB.

Source

impl KeyboardTrackingQueryFlagsFB

pub const EMPTY: KeyboardTrackingQueryFlagsFB

pub fn from_raw(x: u64) -> KeyboardTrackingQueryFlagsFB

pub fn into_raw(self) -> u64

pub fn is_empty(self) -> bool

pub fn intersects(self, other: KeyboardTrackingQueryFlagsFB) -> bool

pub fn contains(self, other: KeyboardTrackingQueryFlagsFB) -> bool

Returns whether other is a subset of self